<?php

/**
 * Plugin Name: WooCommerce Quick Export Plugin
 * Description: Adds a new tab in your WooCommerce reports option page to export all your customers and orders in a CSV file.
 * Version: 1.4.1
 * Author: MB Création
 * Author URI: http://www.mbcreation.net
 * License: http://codecanyon.net/licenses/regular_extended
 *
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


/**
 * WooCommerce_Quick_Export_Plugin
 *
 * @since 1.0
 */



if ( ! class_exists( 'WooCommerce_Quick_Export_Plugin' ) ) {

class WooCommerce_Quick_Export_Plugin{

	private $errors;
	private $included_order_keys = array();
	private $included_order_product_keys = array();

	private $included_user_identity_keys = array();
	private $included_billing_information_keys = array();
	private $included_shipping_information_keys = array();
	private $status_for_user_activity = array();
	
	protected $woocommerce_version;
	

	function __construct()
	{	
		global $woocommerce;
    	$this->woocommerce_version = $woocommerce->version;
    	
		if( class_exists( 'Woocommerce' ) ){
			$this->hooks();
		}
		else{
			add_action( 'woocommerce_loaded', array( &$this, 'hooks' ) );
		}
		
	} //__construct
	
	public function hooks()
	{
		$this->locate();
		
		add_filter( 'woocommerce_reports_charts' , array($this, 'tab' ));
		add_action( 'admin_enqueue_scripts', array($this, 'javascript' ) );
		add_action( 'init', array($this, 'init_class_vars') );
		add_action( 'init', array($this, 'export') );
		add_filter( 'plugin_action_links_'.plugin_basename( __FILE__ ), array($this,'action_links'), 10, 2 );
				
	} //hooks
	
	public function init_class_vars()
	{
		$this->included_order_keys = $this->wqep_included_order_keys();
		$this->included_user_identity_keys = $this->wqep_included_user_identity_keys();
		$this->included_billing_information_keys = $this->wqep_included_billing_information_keys();
		$this->included_shipping_information_keys = $this->wqep_included_shipping_information_keys();
		
		$this->included_order_product_keys = $this->wqep_included_order_product_keys();
		
		$this->status_for_user_activity = $this->wqep_status_for_user_activity();
		$this->errors = array();
	}

	public function locate()
	{	
		load_plugin_textdomain('wqep', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/');
	}

	public function action_links( $links, $file ) {
    	
    	if(substr($this->woocommerce_version, 0, 3) == '2.0')
    	{
    		array_unshift( $links, '<a href="' . admin_url( 'admin.php?page=woocommerce_reports&tab=wqep-export' ) . '">' . __( 'Go to Quick Export', 'wqep' ) . '</a>' );
    	}
    	else
    	{
    		array_unshift( $links, '<a href="' . admin_url( 'admin.php?page=wc-reports&tab=wqep-export' ) . '">' . __( 'Go to Quick Export', 'wqep' ) . '</a>' );
    	}
 		return $links;

	}



	public function javascript($hook){
	
    	if( 'woocommerce_page_woocommerce_reports' != $hook and 'woocommerce_page_wc-reports' != $hook ) return;
    	
    	wp_enqueue_script( 'wqep_custom_script', plugin_dir_url( __FILE__ ) . '/js/wqep-export.js' , array('jquery','jquery-ui-datepicker') );
    	
	} //locate


	public function tab( $charts )
	{

	    $charts['wqep-export'] = array(
			'title'  => __( 'Quick Export', 'wqep' ),
			'charts' => array(
				'overview' => array(
					
					'title'       => __( 'WooCommerce Quick Export Plugin', 'wqep' ),
					'description' => __( 'To quickly export data from your WooCommerce database, just select the data type and click the export button. <br/> For more informations on options, read the html manual included with the plugin. Thanks for using this Plugin.', 'wqep' ),
					'hide_title'  => true,
					'function'    => array($this, 'panel')
				),
			)
		);

		return $charts;
	} //tab


	public function panel()
	{

		if( count( $this->errors ) > 0 ) {
			echo '<div class="error"><ul>'; 
			foreach( $this->errors as $error) {
				echo '<li>'.$error->get_error_message().'</li>';
			}
			echo '</ul></div>'; 
		}
		
		?>
		<div id="poststuff">
		<form id="wqep-form" method="post" action="">
			<div class="postbox">
			<h3><span><?php _e('Data Type', 'wqep');?></span></h3>
			<div class="inside">
			<table class="form-table" id="wqep-form-table-entity">
				<tr valign="top">
					<th scope="row">
						<label for="wqep-entity"><?php _e('Would you like to export customers or orders ?','wqep');?></label>
					</th>

					<td>
						<select name="wqep_type" id="wqep-entity">
							<option value="customers"><?php _e('Customers', 'woocommerce'); ?></option>
							<option value="orders" ><?php _e('Orders', 'woocommerce'); ?></option>
						</select>
					</td>
				</tr>

				<tr valign="top" id="wqep-td-user-infos">

					<th scope="row"><?php _e('User data', 'wqep');?></th>
					
					<td>
						<fieldset>
							<legend class="screen-reader-text"><span><?php _e('User data', 'wqep');?></span></legend>

							<!-- USER IDENTITY -->
							<label for="wqep-userdata-identity">
								<input name="wqep_userdata[]" type="checkbox" id="wqep-userdata-identity" value="identity" checked="checked">
									<?php _e('User identity', 'wqep'); ?>
							</label><br>

							<!-- USER BILLING INFO -->
							<label for="wqep-userdata-billing">
								<input name="wqep_userdata[]" type="checkbox" id="wqep-userdata-billing" value="billing" checked="checked">
									<?php _e('Billing informations', 'wqep'); ?>
							</label><br>

							<!-- USER SHIPPING INFO -->
							<label for="wqep-userdata-shipping">
								<input name="wqep_userdata[]" type="checkbox" id="wqep-userdata-shipping" value="shipping" checked="checked">
									<?php _e('Shipping informations', 'wqep'); ?>
							</label><br>

							<!-- USER SALES INFO -->
							<label for="wqep-userdata-sales">
								<input name="wqep_userdata[]" type="checkbox" id="wqep-userdata-sales" value="sales" >
									<?php _e('Sales statistics', 'wqep'); ?>
							</label><br>

						</fieldset>
					</td>
				</tr>

				<tr valign="top" id="wqep-td-command-status">

					<th scope="row"><?php _e('Order status', 'wqep');?></th>
					
					<td>
						<fieldset>
							<legend class="screen-reader-text"><span><?php _e('Order status', 'wqep');?></span></legend>

							<?php $shop_order_status = get_terms( 'shop_order_status', 'orderby=id&hide_empty=1' ); ?>
							<?php foreach ($shop_order_status as $status): ?>
								<label for="wqep-status-<?php echo $status->slug;?>">
								<input name="wqep_status[]" type="checkbox" id="wqep-status-<?php echo $status->slug;?>" value="<?php echo $status->term_id; ?>" checked="checked">
								<?php _e($status->name, 'woocommerce'); ?> (<?php echo $status->count;?>)
							</label><br>
							<?php endforeach; ?>
					</fieldset>
					</td>
				</tr>

			</table>
			</div>
			</div>
			<div class="postbox">
			<h3><span><?php _e('Optionnals date range', 'wqep');?></span></h3>
			<div class="inside">
			<table class="form-table" id="wqep-form-table-date-range">
				<tr valign="top">
					<th scope="row"><?php _e('Start Date', 'wqep');?></th>
					<td><input readonly="readonly" type="text" class="text custom_date" name="wqep_start_date" value="" /></td>
				</tr>
				<tr valign="top">
					<th scope="row"><?php _e('End Date', 'wqep');?></th>
					<td><input readonly="readonly" type="text" class="text custom_date" name="wqep_end_date" value="" /></td>
				</tr>
			</table>
			</div>
			</div>
			<div class="postbox">
			<h3><span><?php _e('CSV file options', 'wqep');?></span></h3>
			<div class="inside">
			<table class="form-table" id="wqep-form-table-file-options">
				<tr valign="top">
					<th scope="row"><?php _e('Field Separator', 'wqep');?></th>
					<td><input type="text" class="small-text" name="wqep_separator" value="," /></td>
				</tr>
				<tr valign="top">
					<th scope="row"><?php _e('Line Breaks', 'wqep');?></th>
					<td>
						<input type="text" class="small-text" name="wqep_linebreak" value="\r\n" />
					</td>
				</tr>
			</table>


			<input type="hidden" name="wqep_action" value="tocsv" />
			<p class="submit">
				<input type="submit" class="button-primary" value="<?php _e('Export') ?>" />
			</p>
			</div>
			</div>
		</form>
		</div><!-- poststuff -->

		<?php 
	} //panel


	public function wqep_status_for_user_activity()
	{
		$keys = array( 'completed' );

		return apply_filters('wqep_status_for_user_activity_filter', $keys);
	}
	
	public function wqep_included_order_keys()
	{
		$keys = array(
			'id', 'status', 'order_date', 'billing_first_name', 'billing_last_name', 
			'billing_company', 'billing_address_1', 'billing_address_2','billing_city',  
			'billing_postcode', 'billing_country', 'billing_state', 'billing_email', 
			'billing_phone', 'shipping_first_name', 'shipping_last_name', 
			'shipping_company', 'shipping_address_1', 'shipping_address_2', 
			'shipping_city', 'shipping_postcode', 'shipping_state', 'shipping_country',
			'customer_note', 
			'shipping_method_title', 'payment_method_title', 'order_discount', 
			'cart_discount', 'order_tax', 'order_shipping', 'order_shipping_tax', 
			'order_total', 'order_tax_detail', 'completed_date'
		);
			
		return apply_filters('wqep_included_order_keys_filter', $keys);
	}
	
	public function wqep_included_order_product_keys()
	{
		$keys = array();
			
		return apply_filters('wqep_included_order_product_keys_filter', $keys);
	}


	public function wqep_included_user_identity_keys()
	{
		
		$keys = array(
			'user_registered',
			'user_login',
			'user_email'
		);

		return apply_filters('wqep_included_user_identity_keys_filter', $keys);
	
	}

	public function wqep_included_billing_information_keys()
	{
		
		$keys = array(
			'billing_first_name',  'billing_last_name', 'billing_company',
			'billing_address_1', 'billing_address_2', 'billing_city',
			'billing_postcode', 'billing_country', 'billing_state', 
			'billing_email', 'billing_phone'
		);

		return apply_filters('wqep_included_billing_information_keys_filter', $keys);
	
	}

	public function wqep_included_shipping_information_keys()
	{
		
		$keys = array(
			'shipping_first_name', 'shipping_last_name', 'shipping_company', 
			'shipping_address_1', 'shipping_address_2', 'shipping_city', 
			'shipping_postcode', 'shipping_country', 'shipping_state'
		);

		return apply_filters('wqep_included_shipping_information_keys_filter', $keys);
	
	}

	public function export()
	{

		if($_SERVER['REQUEST_METHOD']!=='POST' or !isset($_POST['wqep_action']) or ($_POST['wqep_action']!=='tocsv') or !current_user_can( apply_filters('wqep_caps','administrator')))
			return;

		$csv = '';
		$export_csv = true;

		$sep = (empty($_POST['wqep_separator'])) ? ',' : $_POST['wqep_separator'];
		$lb = (empty($_POST['wqep_linebreak'])) ? "\r\n" : stripslashes_deep( $_POST['wqep_linebreak'] );

		$start = (empty($_POST['wqep_start_date'])) ? '1970-01-01' : $_POST['wqep_start_date'];
		$end = (empty($_POST['wqep_end_date'])) ? '2020-01-01' : $_POST['wqep_end_date'];


		$sep = $this->expand_escape($sep);
		$lb = $this->expand_escape($lb);

		switch ($_POST['wqep_type']) {

			case 'customers':

				$args = array(
					'fields' => 'all_with_meta',
					'role' => 'customer',
					'orderby' => 'user_registered',
					'order' => 'ASC',
				);

				$customers = get_users($args);
				
				foreach($customers as $k => $customer) {
					if($customer->user_registered<$start or $customer->user_registered>$end){
						unset($customers[$k]);
					}
				}

				// calculate order activity if asked
				if(array_search('sales', $_POST['wqep_userdata'])!==false) {

						$customers = $this->addUserActivity($customers);
				}				

				if(array_search('identity', $_POST['wqep_userdata'])!==false){


						foreach ($this->included_user_identity_keys as $key) {

							$key = ucwords(str_replace('_', ' ', $key));
									$key2 = '';
									if(strpos($key, 'Billing')!== false)
									{
										$key = str_replace('Billing', '', $key);
										$key2 = ' ('.__('Billing', 'woocommerce').')';
									}
									if(strpos($key, 'Shipping')!== false)
									{
										$key = str_replace('Shipping', '', $key);
										$key2 = ' ('.__('Shipping', 'woocommerce').')';
									}
									
							$csv.='"'.__(trim($key), 'woocommerce').$key2.'"'.$sep;
						}

						
				}
				
				if(array_search('billing', $_POST['wqep_userdata'])!==false){
						
						foreach ($this->included_billing_information_keys as $key) {
							
						
							$key = ucwords(str_replace('_', ' ', $key));
									$key2 = '';

									if(strpos($key, 'Billing')!== false)
									{
										$key = str_replace('Billing', '', $key);
										$key2 = ' ('.__('Billing', 'woocommerce').')';
									}
								
									
							$csv.='"'.__(trim($key), 'woocommerce').$key2.'"'.$sep;

						}
				}

				if(array_search('shipping', $_POST['wqep_userdata'])!==false){
						
						foreach ($this->included_shipping_information_keys as $key) {
							
						
							$key = ucwords(str_replace('_', ' ', $key));
									$key2 = '';
								
									if(strpos($key, 'Shipping')!== false)
									{
										$key = str_replace('Shipping', '', $key);
										$key2 = ' ('.__('Shipping', 'woocommerce').')';
									}
									
							$csv.='"'.__(trim($key), 'woocommerce').$key2.'"'.$sep;

						}

				}


				if(array_search('sales', $_POST['wqep_userdata'])!==false){

						$csv.='"'.__('Orders count','wqep').'"'.$sep;
						$csv.='"'.__('Orders total','wqep').'"'.$sep;

				}
				
				$csv = rtrim($csv, $sep);
				$csv.=$lb;


				if( count( $customers) == 0) {
					$export_csv = false;
					$this->errors[] = new WP_Error('error', __('No customer to export in that period.', 'wqep'));
				}
				else {

					foreach ($customers as $customer) {

						if(array_search('identity', $_POST['wqep_userdata'])!==false) {

							foreach ($this->included_user_identity_keys as $key) {

								$csv.='"'.str_replace('"', '""', $customer->{$key} ).'"'.$sep;
							
							}
							

						}

						if(array_search('billing', $_POST['wqep_userdata'])!==false) {

							foreach ($this->included_billing_information_keys as $key) {

								$csv.='"'.str_replace('"', '""', $customer->{$key} ).'"'.$sep;
							
							}

						}

						if(array_search('shipping', $_POST['wqep_userdata'])!==false) {

							foreach ($this->included_shipping_information_keys as $key) {

								$csv.='"'.str_replace('"', '""', $customer->{$key} ).'"'.$sep;
							
							}

						}
					

						if(array_search('sales', $_POST['wqep_userdata'])!==false) {

							$csv.='"'.str_replace('"', '""', $customer->wqep_nb_order ).'"'.$sep;
							$csv.='"'.str_replace('"', '""', $customer->wqep_total_orderered ).'"'.$sep;

						}

						$csv = rtrim($csv, $sep);
						$csv.=$lb;
					}

				}
				break;
			
			case 'orders':
				
				$customer_orders = new WP_Query( array(
						'posts_per_page' => -1,
						'post_type'   => 'shop_order',
						'post_status' => 'publish',
						'orderby' => 'post_date',
						'order' => 'ASC',
						'date_query' => array(
								array(
											'after' => $start,
											'before' =>  $end.' 23:59:59',
											'inclusive' => true,
										),
								),
							
						'tax_query'=>array(
								array(

									 'taxonomy' =>'shop_order_status',
									 'field' => 'id',
									 'terms' => $_POST['wqep_status']
								)
						)
					)
				);

				$customer_orders = $customer_orders->get_posts();

				
				$total_orders = (int) sizeof($customer_orders);
				
				//get max items from a commande
				$max_items = $this->getMaxItems($customer_orders);
				$max_coupons = $this->getMaxCoupons($customer_orders);
				
				$i=0;

				if( count( $customer_orders ) == 0) {
					$export_csv = false;
					$this->errors[] = new WP_Error('error', __('No order to export in that period.', 'wqep'));
				}
				else {
					$different_taxes = $this->getDifferentTaxes($customer_orders);
					foreach ( $customer_orders as $customer_order ) {

						$order = new WC_Order();
						$order->populate( $customer_order );

						// adding custom fields.

						// WooCommerce is not loading order meta data anymore
						if(!isset($order->order_custom_fields))
						$order->order_custom_fields = get_post_meta( $order->id );

						foreach ($order->order_custom_fields as $key => $value) {
							$order->$key = $value[0];
						}

						unset( $order->order_custom_fields );


						if($i==0){
							// column names for row one

							foreach ($this->included_order_keys as $key) {
								if($key == 'order_tax_detail' and count($different_taxes) > 1)
								{
									foreach($different_taxes as $taxslug=>$taxname)
										$csv.='"'.str_replace('"', '""',$taxname).'"'.$sep;
								}
								elseif($key != 'order_tax_detail')
								{
								
									$key = ucwords(str_replace('_', ' ', $key));
									$key2 = '';
									if(strpos($key, 'Billing')!== false)
									{
										$key = str_replace('Billing', '', $key);
										$key2 = ' ('.__('Billing', 'woocommerce').')';
									}
									if(strpos($key, 'Shipping')!== false)
									{
										$key = str_replace('Shipping', '', $key);
										$key2 = ' ('.__('Shipping', 'woocommerce').')';
									}
								
									$csv.='"'.__(trim($key), 'woocommerce').$key2.'"'.$sep;
								}
							}
							
							
							$csv.='"'.__('Number of different items', 'wqep').'"'.$sep;
							$csv.='"'.__('Total number of items', 'wqep').'"'.$sep;
							for($i=0; $i<$max_items; $i++)
							{
								$csv.='"'.__('SKU', 'woocommerce').' #'.($i+1).'"'.$sep;
								$csv.='"'.__('Name', 'woocommerce').' #'.($i+1).'"'.$sep;
								$csv.='"'.__('Quantity', 'woocommerce').' #'.($i+1).'"'.$sep;
								foreach ($this->included_order_product_keys as $pdt_key)
								{
									$csv.='"'.$pdt_key.' #'.($i+1).'"'.$sep;
									
								}
							}
								
							$csv.='"'.__('Used coupons', 'wqep').'"'.$sep;
							for($i=0; $i<$max_coupons; $i++)
							{
								$csv.='"'.__('Coupon', 'woocommerce').' #'.($i+1).'"'.$sep;
								$csv.='"'.__('Discount', 'wqep').' #'.($i+1).'"'.$sep;
							}
							
							$csv.=$lb;

						}

						
						foreach ($this->included_order_keys as $key) {
							if(isset($order->$key))
								$csv.='"'.str_replace('"', '""',$order->$key).'"'.$sep;
							else
							{
								if($key == 'order_tax_detail' and count($different_taxes) > 0)
								{
									foreach($different_taxes as $taxslug=>$taxname)
									{
										$tax = $this->getSumTaxes($order->id, $taxslug);
										$csv.='"'.str_replace('"', '""',$tax).'"'.$sep;
									}
								
								}
								elseif($key != 'order_tax_detail')
								{
									$csv.='""'.$sep;
								}
							}	
						}
						
					
						$items = $order->get_items();
						
						//item totals
						$csv.='"'.count($items).'"'.$sep;
						$item_counts = 0;
						foreach($items as $item)
						{
							$item_counts += $item['qty'];
						}
						$csv.='"'.$item_counts.'"'.$sep;
						
						
						$items = array_values($items);
						//items infos
						for($i=0; $i<$max_items; $i++)
						{
							if(isset($items[$i]))
							{
						
								$product = $order->get_product_from_item($items[$i]);
								if($product instanceof WC_Product)
								{
									$csv.='"'.str_replace('"', '""',$product->get_sku()).'"'.$sep;
									$csv.='"'.str_replace('"', '""',$product->get_title()).'"'.$sep;
									$csv.='"'.str_replace('"', '""',$items[$i]['qty']).'"'.$sep;
									
									foreach ($this->included_order_product_keys as $pdt_key)
									{
										$pm = '';
										if($product instanceof WC_Product_Variation)
										{
											$pm = get_post_meta($product->variation_id, $pdt_key, true);
										}
										if(!$pm)
											$pm = get_post_meta($product->id, $pdt_key, true);
										$csv.='"'.str_replace('"', '""',$pm).'"'.$sep;
									}
								}
								else
								{
									$csv.='"'.__('Deleted Item', 'wqep').'"'.$sep.'"'.$items[$i]['name'].'"'.$sep.'"'.$items[$i]['qty'].'"'.$sep;
									
									foreach ($this->included_order_product_keys as $pdt_key)
										$csv.='""'.$sep;
								}
							}
							else
							{
								$csv.='""'.$sep.'""'.$sep.'""'.$sep;
								foreach ($this->included_order_product_keys as $pdt_key)
									$csv.='""'.$sep;
							}
							
						}
						
						//coupons
						$nb_coupons = count($order->get_used_coupons());
						$csv.='"'.$nb_coupons.'"'.$sep;
						foreach($order->get_used_coupons() as $coupon)
						{
							$csv.='"'.str_replace('"', '""',$coupon).'"'.$sep;
							
							$montant_coupon = $this->getCouponAmount($order->id, $coupon);
							$csv.='"'.str_replace('"', '""',$montant_coupon).'"'.$sep;
						}


						$csv.=$lb;
					
						$i++;
					}
				}
				
				break;
			} //switch ($_POST['wqep_type'])


			if($export_csv) {
				
				$filename = $_POST['wqep_type'] .'-'. date( 'Y-m-d_H-i-s' ) . '.csv';
				header( 'Content-Encoding: '. get_option( 'blog_charset' ));
				header( 'Content-Description: File Transfer' );
				header( 'Content-Disposition: attachment; filename=' . $filename );
				header( 'Content-Type: text/csv; charset=' . get_option( 'blog_charset' ), true );
				
				die($csv);
			}

	} //export
	
	
	/**
	 * Add wqep_total_orderered and wqep_nb_order to each user
	 *
	 * @param array $orders : orders to consider to get the max items
	 * @return int number of maximium items
	 */
	private function getMaxItems($post_orders)
	{	
		global $wpdb;
		$ids = array();
		foreach($post_orders as $post)
		{
			$ids[] = $post->ID;
		}
		
		if(count($post_orders)>0)
		{
    		$query = '
    			SELECT MAX(total) as total FROM
    			
    			(SELECT count(*) as total
    				FROM '.$wpdb->prefix.'woocommerce_order_items
    			WHERE 
    				order_item_type = "line_item"
    				AND order_id in ('.implode(', ', $ids).')
    			GROUP BY 
    				order_id
    			ORDER BY total desc) as tmp
    		';
    		
    		$results = $wpdb->get_results($query);
    
    		if(isset($results[0]))
    			return $results[0]->total;
    		else
    			return 0;
        }
		else
            return 0;
	}
	
	
	private function getMaxCoupons($post_orders)
	{	
		global $wpdb;
		$ids = array();
		foreach($post_orders as $post)
		{
			$ids[] = $post->ID;
		}
		
		if(count($post_orders)>0)
		{
    		$query = '
    			SELECT MAX(total) as total FROM
    			
    			(SELECT count(*) as total
    				FROM '.$wpdb->prefix.'woocommerce_order_items
    			WHERE 
    				order_item_type = "coupon"
    				AND order_id in ('.implode(', ', $ids).')
    			GROUP BY 
    				order_id
    			ORDER BY total desc) as tmp
    		';
    		
    		$results = $wpdb->get_results($query);
    
    		if(isset($results[0]))
    			return $results[0]->total;
    		else
    			return 0;
		}
		else
		  return 0;
	}
	
	
	private function getCouponAmount($order_id, $coupon)
	{
		global $wpdb;
		
		$query = '
			SELECT meta_value
				FROM '.$wpdb->prefix.'woocommerce_order_items oi
				LEFT JOIN '.$wpdb->prefix.'woocommerce_order_itemmeta oim
					ON oi.order_item_id = oim.order_item_id
			WHERE 
				order_item_type = "coupon"
				AND order_id ='.$order_id.'
				AND order_item_name="'.mysql_real_escape_string($coupon).'"
				AND meta_key="discount_amount"
		';
		
		$results = $wpdb->get_results($query);

		if(isset($results[0]))
			return round($results[0]->meta_value, 2);
		else
			return 0;
	}
	
	/*
	*	Return an array width the slugs of the taxes used by the set of orders
	*/
	protected function getDifferentTaxes($post_orders)
	{
		global $wpdb;
		$ids = array();
		foreach($post_orders as $post)
		{
			$ids[] = $post->ID;
		}
		
		$query = '
			SELECT order_item_name, meta_value
				FROM '.$wpdb->prefix.'woocommerce_order_items oi, '.$wpdb->prefix.'woocommerce_order_itemmeta oim
			WHERE 
			    oi.order_item_id=oim.order_item_id
				AND oi.order_item_type = "tax"
				AND oi.order_item_name != ""
				AND oi.order_id in ('.implode(', ', $ids).')
				AND meta_key="label"
			GROUP BY 
				oi.order_id, oi.order_item_name
			
		';
		
		$results = $wpdb->get_results($query);

		$tab = array();
		foreach($results as $res)
		{
		   $tab[$res->order_item_name] = $res->meta_value;
		}
		
		return $tab;
	}
	
	/*
	*	Return an the amount of a specific taxe and a specific order
	*/
	protected function getSumTaxes($order_id, $taxslug)
	{
	   global $wpdb;
	   $query = '
			SELECT sum(meta_value) as meta_value
				FROM '.$wpdb->prefix.'woocommerce_order_items oi, '.$wpdb->prefix.'woocommerce_order_itemmeta oim
			WHERE 
			    oi.order_item_id=oim.order_item_id
				AND oi.order_item_type = "tax"
				AND oi.order_id = '.$order_id.'
				AND (meta_key="tax_amount" or meta_key="shipping_tax_amount")
				AND order_item_name= "'.$taxslug.'"
			
			
		';
		//echo $query;exit;
		$results = $wpdb->get_results($query);

		if(isset($results[0]))
			return round($results[0]->meta_value, 2);
		else
			return 0;
	}
	
	/**
	 * Add wqep_total_orderered and wqep_nb_order to each user
	 *
	 * @param array $customers array of customers to calculate activity
	 * @return array $customers with wqep_total_orderered and wqep_nb_order added
	 */
	private function addUserActivity($customers)
	{
		global $wpdb;
		
		$ids = array();
		$tmp = array();
		
		foreach($customers as $customer) {
			$ids[] = $customer->data->ID;
		}
		
		$status = apply_filters('wqep_status_for_user_activity_filter', $this->status_for_user_activity);
		
		if(count($status)==0)
			$status = array('completed');
		
		$status = implode('", "', $status);

		$query = '
			SELECT 
				user.meta_value AS user_id, 
				sum(montant.meta_value) AS wqep_total_orderered, 
				count(*) AS wqep_nb_order 
			FROM '.$wpdb->prefix.'posts 
			LEFT JOIN '.$wpdb->prefix.'postmeta montant 
				ON id=montant.post_ID 
				AND montant.meta_key="_order_total"
			LEFT JOIN '.$wpdb->prefix.'postmeta user
				ON id=user.post_ID 
				AND user.meta_key="_customer_user" 
				
			LEFT JOIN
				'.$wpdb->prefix.'term_relationships wtr
				ON user.post_ID = wtr.object_id
			LEFT JOIN '.$wpdb->prefix.'term_taxonomy wtt
				ON wtt.term_taxonomy_id = wtr.term_taxonomy_id
				AND wtt.taxonomy = "shop_order_status"
			INNER JOIN '.$wpdb->prefix.'terms wt
				ON wt.term_id = wtt.term_id
				AND wt.slug in ("'.$status.'")	
				
			WHERE post_type="shop_order" 
				AND user.meta_value in ('.implode(',', $ids).') 
			GROUP BY user.meta_value
		';
		
		$results = $wpdb->get_results($query);
		foreach($results as $res) {
			$tmp[$res->user_id] = $res;
		}
		
		foreach($customers as $i => $customer) {
			if(isset($tmp[$customer->data->ID]))
			{
				$customers[$i]->wqep_total_orderered = $tmp[$customer->data->ID]->wqep_total_orderered;
				$customers[$i]->wqep_nb_order = $tmp[$customer->data->ID]->wqep_nb_order;
			}
		}
		
		return $customers;
	} //addUserActivity

	public function expand_escape($string) {
		return preg_replace_callback(
			'/\\\([nrtvf]|[0-7]{1,3}|[0-9A-Fa-f]{1,2})?/',
			create_function(
				'$matches',
				'return ($matches[0] == "\\\\") ? "" : eval( sprintf(\'return "%s";\', $matches[0]) );'
			),
			$string
		);
	}

} //WooCommerce_Quick_Export_Plugin
}

function WooCommerce_Simple_Quick_Export_Plugin_Loader() {
	if( class_exists('Woocommerce') ){
		if(is_admin())
			$WooCommerce_Quick_Export_Plugin = new WooCommerce_Quick_Export_Plugin();
	}
}

add_action( 'plugins_loaded' , 'WooCommerce_Simple_Quick_Export_Plugin_Loader');


